@@ -74,6 +74,20 @@ class BrailleGenerator(generator.Generator):
         globalsDict['Link'] = braille.Link
         globalsDict['asString'] = self.asString
 
+    def _isCandidateFocusedRegion(self, obj, region):
+        if not isinstance(region, (braille.Component, braille.Text)):
+            return False
+
+        try:
+            sameRole = obj.getRole() == region.accessible.getRole()
+            sameName = obj.name == region.accessible.name
+        except:
+            msg = 'ERROR: Could not get names, roles for %s, %s' % (obj, region.accessible)
+            debug.println(debug.LEVEL_INFO, msg)
+            return False
+
+        return sameRole and sameName
+
     def generateBraille(self, obj, **args):
         if not _settingsManager.getSetting('enableBraille') \
            and not _settingsManager.getSetting('enableBrailleMonitor'):
@@ -117,6 +131,12 @@ class BrailleGenerator(generator.Generator):
                  and region.accessible.parent == obj:
                 focusedRegion = region
                 break
+        else:
+            candidates = list(filter(lambda x: self._isCandidateFocusedRegion(obj, x), result))
+            msg = 'INFO: Could not determine focused region. Candidates: %i' % len(candidates)
+            debug.println(debug.LEVEL_INFO, msg)
+            if len(candidates) == 1:
+                focusedRegion = candidates[0]
 
         return [result, focusedRegion]
 
@@ -252,7 +272,7 @@ class BrailleGenerator(generator.Generator):
 
         # Radio button group names are treated separately from the
         # ancestors.  However, they can appear in the ancestry as a
-        # labeled panel.  So, we need to exlude the first one of
+        # labeled panel.  So, we need to exclude the first one of
         # these things we come across.  See also the
         # generator.py:_generateRadioButtonGroup method that is
         # used to find the radio button group name.
@@ -325,6 +345,31 @@ class BrailleGenerator(generator.Generator):
 
         return result
 
+    def _generateTermValueCount(self, obj, **args):
+        count = self._script.utilities.getValueCountForTerm(obj)
+        if count < 0:
+            return []
+
+        return ["(%s)" % messages.valueCountForTerm(count)]
+
+    def _generateStatusBar(self, obj, **args):
+        statusBar = self._script.utilities.statusBar(obj)
+        if not statusBar:
+            return []
+
+        items = self._script.utilities.statusBarItems(obj)
+        if not items or items == [statusBar]:
+            return []
+
+        result = []
+        for child in items:
+            childResult = self.generate(child, includeContext=False)
+            if childResult:
+                result.extend(childResult)
+                result.append(braille.Region(" "))
+
+        return result
+
     def _generateListBoxItemWidgets(self, obj, **args):
         widgetRoles = [pyatspi.ROLE_CHECK_BOX,
                        pyatspi.ROLE_COMBO_BOX,
@@ -359,7 +404,11 @@ class BrailleGenerator(generator.Generator):
            and not self._shouldPresentProgressBarUpdate(obj, **args):
             return []
 
-        return self._generatePercentage(obj, **args)
+        result = self._generatePercentage(obj, **args)
+        if obj == orca_state.locusOfFocus and not result:
+            return ['']
+
+        return result
 
     def _generatePercentage(self, obj, **args):
         percent = self._script.utilities.getValueAsPercent(obj)
@@ -410,24 +459,6 @@ class BrailleGenerator(generator.Generator):
             self._restoreRole(oldRole, args)
         return result
 
-    def _generateComboBoxTextObj(self, obj, **args):
-        """For a combo box, we check to see if the text is editable. If so,
-        then we want to show the text attributes (such as selection --
-        see bug 496846 for more details).  This will return an array
-        containing a single object, which is the accessible for the
-        text object. Note that this is different from the rest of the
-        generators, which all return an array of strings.  Yes, this
-        is a hack.
-        """
-        result = []
-        textObj = None
-        for child in obj:
-            if child and child.getRole() == pyatspi.ROLE_TEXT:
-                textObj = child
-        if textObj and textObj.getState().contains(pyatspi.STATE_EDITABLE):
-            result.append(textObj)
-        return result
-
     def _generateIncludeContext(self, obj, **args):
         """Returns True or False to indicate whether context should be
         included or not.
